@@ -26,6 +26,11 @@ func validateOptions(options *types.Options) error {
 	if len(options.URLs) == 0 && !fileutil.HasStdin() {
 		return errorutil.New("no inputs specified for crawler")
 	}
+
+	if options.Headless && options.Passive {
+		return errorutil.New("headless mode (-headless) and passive mode (-passive) cannot be used together")
+	}
+
 	if (options.HeadlessOptionalArguments != nil || options.HeadlessNoSandbox || options.SystemChromePath != "") && !options.Headless {
 		return errorutil.New("headless mode (-hl) is required if -ho, -nos or -scp are set")
 	}
